# SnailPy - A python package to interact with Snail IDE's public APIS
![costume1](https://github.com/Snail-IDE/SnailPy/assets/130254323/32ec9147-a77d-4593-9450-686b8f6e32f8)


# Docs
To install SnailPy, all you have to do is use the following command in the terminal
```bash
pip install snailpy
```
Now lets make a python file, start by importing SnailPy
```python
import snailpy
```
You should automatically see something like this in the shell
```bash
You are successfully using SnailPy [VERSION NUMBER HERE]
```

# DOCS WIP THIS IS ALL THAT THERE IS RIGHT NOW
